@@ -31,8 +31,7 @@ else :
 print(DisplayName + "Try:  Loading DLL (" + dllName + ")")
 
 try:
-    #Load_DLL = WinDLL(dllName)
-    Load_DLL = WinDLL('./' + dllName)
+    Load_DLL = WinDLL(dllName)
 except OSError as err:
     print("OS error: {0}".format(err))
     print("Load DLL from CurrentFolder " + "(./" + dllName + ")")
